from setuptools import setup
setup(name='my-test-hello-library',
      version='0.3',
      description='sum two numbers',
      url='https://github.com/sebasgverde/mytesthellolibrary',
      author='Sebastian Garcia Valencia',
      author_email='sebasgverde@gmail.com',
      license='MIT',
      packages=['mytesthellolibrary'],
      python_requires='>=2.7',
      install_requires=[])